clc
clear all
close all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%LOCAL BARRIER MODEL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% INPUT

L=30000; %length
n_tb=9; %number of transverse bulkheads
B=20000; %x-section width
H=12000; %x-section height
S=500; %stiffener distance (mind v_trz and v_trx compatibility)

s_w_HAZ=20; %Width of HAZ region in the stiffener web
s_w=200; %stiffener web height
s_w_rest=s_w-s_w_HAZ; %Rest height of web when HAZ is subtract
s_f=90; %stiffener flange width

%start patran, set directory, choose code 
fid=fopen('local_barrier.db.jou','w'); 
fprintf(fid,'uil_file_rebuild.start("C:\\MSC.Software\\Patran_x64\\20121/template.db", @\r\n'); 
fprintf(fid,'"C:\\work_patran\\local_barrier\\local_barrier.db")\r\n'); 
fprintf(fid,'set_current_dir( "C:\\work_patran\\local_barrier" )\r\n'); 
fprintf(fid,'sys_poll_option( 0 )\r\n'); 
fprintf(fid,'uil_pref_analysis.set_analysis_preference( "LS-DYNA3D", "Structural", ".key", @\r\n'); 
fprintf(fid,'"", "No Mapping" )\r\n');

%% CREATE GROUP "BULKHEAD_HORIZONTAL" AND SET CURRENT
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "bulkhead_horizontal" )\r\n'); 
fprintf(fid,'ga_group_current_set( "bulkhead_horizontal" )\r\n'); 

%create points 
l=L/(n_tb+1); %distance between transvese bulkheads

fprintf(fid,'STRING asm_create_grid_xyz_created_ids[VIRTUAL]\r\n'); 
for i=1:n_tb+2 
    fprintf(fid,'asm_const_grid_xyz( "%.0f", "[0 %.0f 0]", "Coord 0", @\r\n',i,l*(i-1)); 
    fprintf(fid,'asm_create_grid_xyz_created_ids )\r\n'); 
end

%create curves 
fprintf(fid,'STRING asm_line_2point_created_ids[VIRTUAL]\r\n');
for i=1:n_tb+1 
    fprintf(fid,'asm_const_line_2point( "%.0f", "point %.0f", "point %.0f", 0, "", 50., 1, @\r\n',i,i,i+1); 
    fprintf(fid,'asm_line_2point_created_ids )\r\n'); 
end
n_curve=i; %number of curves 

%create surfaces for bottom panel 
n_surf_b=B/S; %number of surfaces in width direction (x-dir) 

n_surf_bh_start=1;

fprintf(fid,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\r\n'); 
for i=1:n_surf_b*n_curve 
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<%.0f 0 0>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',i,S); 
    if i<=n_curve 
        fprintf(fid,'"Curve %.0f", sgm_sweep_surface_e_created_ids )\r\n',i); 
    elseif i>n_curve 
        fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',i-n_curve); 
    end
end
n_surf_hb1=i; %number of surfaces in horizontal bulkhead 1 

%copying surfaces to create remaining horizontal bulkheads 
n_hb=4; %number of horizontal bulkheads 
h=H/(n_hb-1); 
v_trz=[H/3,2*H/3,H]; %translation vector 

n_surf=0; 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
if n_hb==3 
    fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf_hb1+1,h,h); 
    fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',n_hb-1,n_surf+1,n_surf_hb1); 
elseif n_hb==4 
    for i=1:n_hb-1 
        fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',i*n_surf_hb1+1,v_trz(i),v_trz(i)); 
        fprintf(fid,'"Coord 0", 1, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',n_surf+1,n_surf_hb1); 
    end
end
n_surf=n_surf_hb1*n_hb;
n_surf_bh_end=n_surf;

%% CREATING GROUP "BULKHEAD_VERTICAL" AND MAKING IT CURRENT
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "bulkhead_vertical" )\r\n');
fprintf(fid,'ga_group_current_set( "bulkhead_vertical" )\r\n'); 

%creating vertical bulkheads 
n_surf_h=H/S; %number of surfaces in height direction (z-dir) 
n_surf_preVB=n_surf; 

n_surf_bv_start=1+n_surf;

fprintf(fid,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\r\n'); 
for i=1:n_surf_h*n_curve
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 0 %.0f>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',i+n_surf,S); 
    if i<=n_curve 
        fprintf(fid,'"Curve %.0f", sgm_sweep_surface_e_created_ids )\r\n',i); 
    elseif i>n_curve 
        fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',(i-n_curve)+n_surf); 
    end
end
n_surf_vb1=i; %number of surfaces in vertical bulkhead 1 

n_surf=n_surf+n_surf_vb1; 

%copying surfaces to create remaining vertical bulkheads 
n_vb=4; %number of vertical bulkheads 
b=B/(n_vb-1); 
v_trx=[.35*B,.65*B,B]; 

fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
if n_vb==3 
    fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,b,b); 
    fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',n_vb-1,n_surf-n_surf_vb1+1,n_surf); 
elseif n_vb==4 
    for i=1:n_vb-1 
        fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1+(i-1)*n_surf_vb1,v_trx(i),v_trx(i)); 
        fprintf(fid,'"Coord 0", 1, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',n_surf+1-n_surf_vb1,n_surf); 
    end
end

n_surf=n_surf+n_surf_vb1*(n_vb-1);

n_surf_bv_end=n_surf;

%% CREATING GROUP "BULKHEAD_TRANSVERSE" AND MAKING IT CURRENT
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "bulkhead_transverse" )\r\n'); 
fprintf(fid,'ga_group_current_set( "bulkhead_transverse" )\r\n'); 

n_surf_bt_start=n_surf+1;

% creating transvers bulkheads 
n=1-n_surf_h; 
j=0; 
for i=1:n_surf_hb1 
    if rem(i,n_curve)==0 
    
    else
        n=n+n_surf_h; 
        j=j+1; 
        fprintf(fid,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\r\n'); 
        fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 0 %.0f>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+n,S); 
        fprintf(fid,'"Surface %.0f.3", sgm_sweep_surface_e_created_ids )\r\n',i); 
        
        fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n');
        fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+n+1,S,S); 
        fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f", sgm_transform_surf__created_ids )\r\n',n_surf_h-1,n_surf+n); 
    end
end
n_surf=n_surf+j*n_surf_h;
n_surf_bt_end=n_surf;

%% CREATING GROUP "STIFFENERS_TB" AND MAKING IT CURRENT
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "stiffeners_tb_HAZ" )\r\n'); 
fprintf(fid,'ga_group_current_set( "stiffeners_tb_HAZ" )\r\n'); 

s_tb=200; %stiffener web height, transeverse bulkhead 
s_tb_HAZ=20; %HAZ height for transversal bulkhead stiffeners
s_tb_rest=s_tb-s_tb_HAZ; %Rest height of web when HAZ is subtract

n_surf_stiffener_tb_HAZ_start=n_surf+1;

for i=1:n_tb 
    fprintf(fid,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\r\n'); 
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 %.0f 0>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_tb_HAZ); 
    fprintf(fid,'"Surface %.0f.3", sgm_sweep_surface_e_created_ids )\r\n',n_surf-j*n_surf_h+n_surf_h*(i-1)+1); 
end
n_surf=n_surf+i; 

%copying stiffeners_tb in vertical direction 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,S,S); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',n_surf_h-1,n_surf-i+1,n_surf); 
n_surf=n_surf+i*(n_surf_h-1); 

%copying stiffeners_tb in horizontal direction 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,S,S);
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',12,n_surf-n_tb*n_surf_h+1,n_surf); 
n_surf=n_surf+12*i*n_surf_h; 

%copying stiffeners_tb from compartments at one endt to the other edge 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,v_trx(2),v_trx(2)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-13*n_tb*n_surf_h+1,n_surf); 
n_surf=n_surf+13*i*n_surf_h; 

%copying stiffeners_tb from compartments at one endt to the senter %compartments 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,-v_trx(1),-v_trx(1)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids)\r\n',1,n_surf-11*n_tb*n_surf_h+1,n_surf); 
n_surf=n_surf+11*i*n_surf_h;

n_surf_tb_HAZ=11*i*n_surf_h+13*i*n_surf_h+12*i*n_surf_h+i*(n_surf_h-1)+i; %DENNE HAR JEG LAGT TIL FOR  KUNNE LEGGE TIL HAZ OMRDE

n_surf_stiffener_tb_HAZ_end=n_surf;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "stiffeners_tb_rest" )\r\n'); 
fprintf(fid,'ga_group_current_set( "stiffeners_tb_rest" )\r\n'); 

n_surf_stiffener_tb_rest_start=n_surf+1;

for i=1:n_tb 
    fprintf(fid,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\r\n'); 
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 %.0f 0>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_tb_rest); 
    fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',n_surf-n_surf_tb_HAZ+i);
end
n_surf=n_surf+i; 

%copying stiffeners_tb in vertical direction 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,S,S); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',n_surf_h-1,n_surf-i+1,n_surf); 
n_surf=n_surf+i*(n_surf_h-1); 

%copying stiffeners_tb in horizontal direction 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,S,S);
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',12,n_surf-n_tb*n_surf_h+1,n_surf); 
n_surf=n_surf+12*i*n_surf_h; 

%copying stiffeners_tb from compartments at one endt to the other edge 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,v_trx(2),v_trx(2)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-13*n_tb*n_surf_h+1,n_surf); 
n_surf=n_surf+13*i*n_surf_h; 

%copying stiffeners_tb from compartments at one endt to the senter %compartments 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,-v_trx(1),-v_trx(1)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids)\r\n',1,n_surf-11*n_tb*n_surf_h+1,n_surf); 
n_surf=n_surf+11*i*n_surf_h;

n_surf_stiffener_tb_rest_end=n_surf;


%% CREATE STIFFENERS
%creating group "stiffeners_web_HAZ" and making it current 
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "stiffeners_web_HAZ" )\r\n'); 
fprintf(fid,'ga_group_current_set( "stiffeners_web_HAZ" )\r\n');

n_surf_stiffener_web_HAZ_1_start=n_surf+1;

%create first longitudinal stiffener on horizontal bulkhead 1 
for i=1:n_curve 
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 0 %.0f>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_w_HAZ); 
    %fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',i+n_curve); 
    fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',i); 
end
n_surf=n_surf+i; 

%copy stiffener along width, --> 1 transverse bulkhead 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,S,S); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',12,n_surf-i+1,n_surf); 
n_surf=n_surf+12*i; 

% --> 2 transverse bulkhead 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,6000,6000); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-11*i+1,n_surf); 

% --> 3 transverse bulkhead 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+11*i+1,13000,13000); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-13*i+1,n_surf); 
n_surf=n_surf+(11+13)*i; 

%translating stiffener-webs in z-dir 
%--> 2 deck 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,v_trz(1)-s_w_HAZ,v_trz(1)-s_w_HAZ); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-(13+11+13)*i+1,n_surf); 

%--> 3 deck 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+(13+11+13)*i+1,v_trz(2)-s_w_HAZ,v_trz(2)-s_w_HAZ); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-(13+11+13)*i+1,n_surf);

%--> 4 deck 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+(13+11+13)*i*2+1,v_trz(3)-s_w_HAZ,v_trz(3)-s_w_HAZ); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-(13+11+13)*i+1,n_surf); 
n_surf=n_surf+(13+11+13)*i*3; 

n_surf_web_HAZ=(13+11+13)*i*3+(11+13)*i+12*i+i;

n_surf_stiffener_web_HAZ_1_end=n_surf;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%creating group "stiffeners_web_rest" and making it current 
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "stiffeners_web_rest" )\r\n'); 
fprintf(fid,'ga_group_current_set( "stiffeners_web_rest" )\r\n');

n_surf_stiffener_web_rest_1_start=n_surf+1;

%create first longitudinal stiffener on horizontal bulkhead 1 
for i=1:n_curve 
    fprintf(fid,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\r\n'); 
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 0 %.0f>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_w_rest); 
    fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',n_surf-n_surf_web_HAZ+i); 
end
n_surf=n_surf+i; 

%copy stiffener along width, --> 1 transverse bulkhead 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,S,S); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',12,n_surf-i+1,n_surf); 
n_surf=n_surf+12*i; 

% --> 2 transverse bulkhead 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,6000,6000); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-11*i+1,n_surf); 

% --> 3 transverse bulkhead 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+11*i+1,13000,13000); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-13*i+1,n_surf); 
n_surf=n_surf+(11+13)*i; 

%translating stiffener-webs in z-dir 
%--> 2 deck 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,v_trz(1)-s_w_rest-2*s_w_HAZ,v_trz(1)-s_w_rest-2*s_w_HAZ); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-(13+11+13)*i+1,n_surf); 

%--> 3 deck 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+(13+11+13)*i+1,v_trz(2)-s_w_rest-2*s_w_HAZ,v_trz(2)-s_w_rest-2*s_w_HAZ); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-(13+11+13)*i+1,n_surf);

%--> 4 deck 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+(13+11+13)*i*2+1,v_trz(3)-s_w_rest-2*s_w_HAZ,v_trz(3)-s_w_rest-2*s_w_HAZ); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-(13+11+13)*i+1,n_surf); 
n_surf=n_surf+(13+11+13)*i*3; 

n_surf_stiffener_web_rest_1_end=n_surf;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%creating group "stiffeners_flange" and making it current 
fprintf(fid,'sys_poll_option( 2 )\r\n'); 
fprintf(fid,'ga_group_create( "stiffeners_flange" )\r\n'); 
fprintf(fid,'ga_group_current_set( "stiffeners_flange" )\r\n'); 

n_surf_stiffener_f_1_start=n_surf+1;

%create flanges on horizontal stiffeners 
for i=1:(13+11+13)*n_curve*4 
    if i<=(13+11+13)*n_curve 
        fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<%.0f 0 0>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_f); 
        fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',n_surf-(13+11+13)*n_curve*4+i); 
    else
        fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<%.0f 0 0>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_f); 
        fprintf(fid,'"Surface %.0f.4", sgm_sweep_surface_e_created_ids )\r\n',n_surf-(13+11+13)*n_curve*4+i); 
    end
end
n_surf=n_surf+i; 

n_surf_stiffener_f_1_end=n_surf;

%FLERE STIFFENER WEB
%create first longitudinal stiffener on vertical bulkhead 1 
fprintf(fid,'ga_group_current_set( "stiffeners_web_HAZ" )\r\n'); 

n_surf_stiffener_web_HAZ_2_start=n_surf+1;

fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
for i=1:n_curve 
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<%.0f 0 0>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_w_HAZ); 
    fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',n_surf_preVB+i); 
end
n_surf=n_surf+i; 

%create stiffener web on first vertival bulkhead from bottom to deck 2 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,S,S); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',6,n_surf-i+1,n_surf); 
n_surf=n_surf+i*6; 

%copying stiffeners to compartments between deck 2 and 3, and 4 and 5 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,v_trz(1),v_trz(1)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',2,n_surf-7*i+1,n_surf); 
n_surf=n_surf+i*7*2; 

%copying stiffners from first vertical bulkhead to fourth vertical bulkhead
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,B-s_w_HAZ,B-s_w_HAZ); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-7*i*3+1,n_surf); 
%n_surf=n_surf+7*i*3; 

%copying stiffners from first vertical bulkhead to fourth vertical bulkhead
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1+7*i*3,v_trx(1),v_trx(1)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-7*i*3+1,n_surf); 

%copying stiffners from first vertical bulkhead to fourth vertical bulkhead
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1+7*i*3*2,v_trx(2),v_trx(2)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-7*i*3+1,n_surf); 

n_surf=n_surf+3*7*i*3; 

n_surf_flere=3*7*i*3+i*7*2+i*6+i;

n_surf_stiffener_web_HAZ_2_end=n_surf;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%create first longitudinal stiffener on vertical bulkhead 1 
fprintf(fid,'ga_group_current_set( "stiffeners_web_rest" )\r\n'); 

n_surf_stiffener_web_rest_2_start=n_surf+1;

fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
for i=1:n_curve 
    fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<%.0f 0 0>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,s_w_rest); 
    fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',n_surf-n_surf_flere+i); 
end
n_surf=n_surf+i; 

%create stiffener web on first vertival bulkhead from bottom to deck 2 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,S,S); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',6,n_surf-i+1,n_surf); 
n_surf=n_surf+i*6; 

%copying stiffeners to compartments between deck 2 and 3, and 4 and 5 
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<0 0 %.0f>", %.0f., FALSE, @\r\n',n_surf+1,v_trz(1),v_trz(1)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',2,n_surf-7*i+1,n_surf); 
n_surf=n_surf+i*7*2; 

%copying stiffners from first vertical bulkhead to fourth vertical bulkhead
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1,B-s_w_rest-s_w_HAZ*2,B-s_w_rest-s_w_HAZ*2); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-7*i*3+1,n_surf); 

%copying stiffners from first vertical bulkhead to fourth vertical bulkhead
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1+7*i*3,v_trx(1),v_trx(1)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-7*i*3+1,n_surf); 

%copying stiffners from first vertical bulkhead to fourth vertical bulkhead
fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 
fprintf(fid,'sgm_transform_translate_v1( "%.0f", "surface", "<%.0f 0 0>", %.0f., FALSE, @\r\n',n_surf+1+7*i*3*2,v_trx(2),v_trx(2)); 
fprintf(fid,'"Coord 0", %.0f, FALSE, "Surface %.0f:%.0f", sgm_transform_surf__created_ids )\r\n',1,n_surf-7*i*3+1,n_surf); 

n_surf=n_surf+3*7*i*3; 



n_surf_stiffener_web_rest_2_end=n_surf;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%create stiffener flanges 
fprintf(fid,'ga_group_current_set( "stiffeners_flange" )\r\n'); 

fprintf(fid,'STRING sgm_transform_surf__created_ids[VIRTUAL]\r\n'); 

n_surf_stiffener_f_2_start=n_surf+1;

for i=1:(21*n_curve*2+21*n_curve*2) 
    if i>21*n_curve && i<=21*n_curve*2 
        fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 0 %.0f>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,-s_f); 
        fprintf(fid,'"Surface %.0f.4", sgm_sweep_surface_e_created_ids )\r\n',n_surf-(21*n_curve*2+21*n_curve*2)+i); 
    else
        fprintf(fid,'sgm_const_surface_extrude( "%.0f", "<0 0 %.0f>", 1., 0., "[0 0 0]", "Coord 0", @\r\n',n_surf+i,-s_f); 
        fprintf(fid,'"Surface %.0f.2", sgm_sweep_surface_e_created_ids )\r\n',n_surf-(21*n_curve*2+21*n_curve*2)+i); 
    end
end
n_surf=n_surf+i; 

n_surf_stiffener_f_2_end=n_surf;


%% MESH
mesh_size=100;

fprintf(fid,'ui_exec_function( "mesh_seed_display_mgr", "init" )\r\n');

fprintf(fid,'INTEGER fem_create_mesh_surfa_num_nodes\r\n');
fprintf(fid,'INTEGER fem_create_mesh_surfa_num_elems\r\n');
fprintf(fid,'STRING fem_create_mesh_s_nodes_created[VIRTUAL]\r\n');
fprintf(fid,'STRING fem_create_mesh_s_elems_created[VIRTUAL]\r\n');

fprintf(fid,'fem_create_mesh_surf_4( "IsoMesh", 49152, "Surface %.0f:%.0f", 1, ["%.0f"],  @\r\n',1,n_surf,mesh_size); %
fprintf(fid,'"Quad4", "#", "#", "Coord 0", "Coord 0", fem_create_mesh_surfa_num_nodes,  @\r\n');
fprintf(fid,'fem_create_mesh_surfa_num_elems, fem_create_mesh_s_nodes_created,  @\r\n');
fprintf(fid,'fem_create_mesh_s_elems_created )\r\n');

fprintf(fid,'ui_exec_function( "mesh_seed_display_mgr", "init" )\r\n');
fprintf(fid,'mesh_seed_display_mgr.erase(  )\r\n');
fprintf(fid,'REAL fem_equiv_all_x_equivtol_ab\r\n');
fprintf(fid,'INTEGER fem_equiv_all_x_segment\r\n');
fprintf(fid,'fem_equiv_all_group4( [" "], 0, "", 1, 1, 5., FALSE,  @\r\n');
fprintf(fid,'fem_equiv_all_x_equivtol_ab, fem_equiv_all_x_segment )\r\n');

%% Material (dummy)
fprintf(fid,'material.create( "Analysis code ID", 10001, "Analysis type ID", 1, "dummy", 0, @\r\n');
fprintf(fid,' "", "Isotropic", 1, "Directionality", 1, "Linearity", 1, "Homogeneous", 0,  @\r\n');
fprintf(fid,'"Linear Elastic", 1, "Model Options & IDs", ["Linear Elastic(MAT1)", "Solid",  @\r\n');
fprintf(fid,'"", "", ""], [11002, 11003, 0, 0, 0], "Active Flag", 1, "Create", 10,  @\r\n');
fprintf(fid,'"External Flag", FALSE, "Property IDs", ["Density", "Elastic Modulus",  @\r\n');
fprintf(fid,'"Poisson Ratio"], [16, 2, 5, 0], "Property Values", ["2700E-9", "70E6", "0.33" @\r\n');
fprintf(fid,', ""] )\r\n');

%%Properties
t_bh=15;
t_bt=15;
t_bv=15;

t_stiffener_f=15;
t_stiffener_tb_HAZ=10;
t_stiffener_tb_rest=10;
t_stiffener_web_HAZ=11.5;
t_stiffener_web_rest=11.5;

fprintf(fid,'elementprops_create( "bulkhead_horizontal", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface %.0f:%.0f" )\r\n',t_bh,n_surf_bh_start,n_surf_bh_end);

fprintf(fid,'elementprops_create( "bulkhead_transverse", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface %.0f:%.0f" )\r\n',t_bt,n_surf_bt_start,n_surf_bt_end);

fprintf(fid,'elementprops_create( "bulkhead_vertical", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface %.0f:%.0f" )\r\n',t_bv,n_surf_bv_start,n_surf_bv_end);

fprintf(fid,'elementprops_create( "stiffeners_f", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface  %.0f:%.0f %.0f:%.0f" )\r\n',t_stiffener_f,n_surf_stiffener_f_1_start,n_surf_stiffener_f_1_end,n_surf_stiffener_f_2_start,n_surf_stiffener_f_2_end);

fprintf(fid,'elementprops_create( "stiffeners_tb_HAZ", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface %.0f:%.0f" )\r\n',t_stiffener_tb_HAZ,n_surf_stiffener_tb_HAZ_start,n_surf_stiffener_tb_HAZ_end);

fprintf(fid,'elementprops_create( "stiffeners_tb_rest", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface %.0f:%.0f" )\r\n',t_stiffener_tb_rest,n_surf_stiffener_tb_rest_start,n_surf_stiffener_tb_rest_end);

fprintf(fid,'elementprops_create( "stiffeners_web_HAZ", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface %.0f:%.0f %.0f:%.0f" )\r\n',t_stiffener_web_HAZ,n_surf_stiffener_web_HAZ_1_start,n_surf_stiffener_web_HAZ_1_end,n_surf_stiffener_web_HAZ_2_start,n_surf_stiffener_web_HAZ_2_end);

fprintf(fid,'elementprops_create( "stiffeners_web_rest", 51, 25, 35, 11004, 1, 20, [13, 20, @\r\n');
fprintf(fid,' 36, 1004, 11044, 11136, 11027, 1011, 11182], [5, 2, 1, 1, 4, 3, 4, 1, 1], [ @\r\n');
fprintf(fid,'"m:dummy", "", "%.0f", "", "", "5", "", "", ""], "Surface %.0f:%.0f %.0f:%.0f" )\r\n',t_stiffener_web_rest,n_surf_stiffener_web_rest_1_start,n_surf_stiffener_web_rest_1_end,n_surf_stiffener_web_rest_2_start,n_surf_stiffener_web_rest_2_end);


%saving
fprintf(fid,'uil_primary_file.db_save( )\r\n'); 


fclose(fid);









